package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````$"D```````!``````````*C!````
M`````````$``.``-`$``'@`=``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````-@5````````V!4`````````
M$`````````$````%`````"``````````(``````````@````````C4(`````
M``"-0@`````````0`````````0````0`````<`````````!P`````````'``
M``````!`2````````$!(`````````!`````````!````!@```,"[````````
MP,L```````#`RP```````&@$````````V`0`````````$`````````(````&
M````\+L```````#PRP```````/#+``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,```````!0````````
M`%``````````"``````````$````!````(@#````````B`,```````"(`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````4`````````!0``````````@`````````4.5T9`0`
M``"PL````````+"P````````L+`````````$`0````````0!````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````P+L```````#`RP```````,#+````
M````0`0```````!`!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````0`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````!``'`!`````D``````````@`!P`0````!````
M``````0````4`````P```$=.50`%Q+6`CGI/0KO5>#KMU&UP8M/9H@0````0
M`````0```$=.50```````P````(```````````````@````_`````0````8`
M```0"8$`P`%``C\```!``````````$$```!"`````````$,`````````T67.
M;3GRBQP+BA!7Q;F<0*?=HVL`````````````````````````````````````
M<0```!(`````````````````````````>P```!(`````````````````````
M````>P$``!(`````````````````````````>P(``!(`````````````````
M````````3`(``!(`````````````````````````AP```!(`````````````
M`````````````0```"``````````````````````````EP$``!(`````````
M````````````````WP(``!(`````````````````````````\0$``!(`````
M````````````````````S0(``!(`````````````````````````(`$``!(`
M````````````````````````N0```!(`````````````````````````80``
M`!(`````````````````````````S0$``!(`````````````````````````
MZP$``!(`````````````````````````YP```!(`````````````````````
M````]@$``!(`````````````````````````&`(``!(`````````````````
M````````VP$``!(`````````````````````````$````"``````````````
M````````````W````!(`````````````````````````=@```!(`````````
M````````````````Y`$``!(`````````````````````````+````"``````
M````````````````````6P(``!(`````````````````````````F`(``!(`
M````````````````````````"0(``!(`````````````````````````4P``
M`!(`````````````````````````)P$``!8`````````````````````````
M!`$``!(`````````````````````````6P$``!(`````````````````````
M````J````!(`````````````````````````]0```!(`````````````````
M````````Q0$``!(`````````````````````````O@$``!(`````````````
M````````````S0```!(`````````````````````````'P(``!(`````````
M````````````````D0(``!(`````````````````````````F@```!(`````
M````````````````````O`(``!(`````````````````````````K@$``!(`
M````````````````````````3P$``!(`````````````````````````A@$`
M`!(`````````````````````````M0(``!(`````````````````````````
MU`$``!(`````````````````````````6@(``!(`````````````````````
M````H`(``!(`````````````````````````.@$``!(`````````````````
M````````%`$``!(`````````````````````````G`$``!(`````````````
M````````````M0$``!(`````````````````````````,`(``!(`````````
M````````````````IP(``!(`````````````````````````*`(``!(`````
M````````````````````P@```!(`````````````````````````/@(``!(`
M````````````````````````;`$``!(`````````````````````````8@(`
M`!(`````````````````````````K@(``!(`````````````````````````
MI`$``!(``````````````````````````P(``!(`````````````````````
M````@@(``"(`````````````````````````=`(``!$`&P!@T`````````@`
M````````1@```!$`&P!PT`````````$`````````U0(``!$`&P!`T```````
M``@`````````UP(``"$`&P!`T`````````@``````````%]?9VUO;E]S=&%R
M=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!097)L7W-Y<U]T97)M`%!E<FQ?
M9W9?9F5T8VAP=@!P97)L7V9R964`4&5R;%]G971?<W8`4&5R;%]A=&9O<FM?
M=6YL;V-K`'!E<FQ?9&5S=')U8W0`4&5R;%]N97=84U]F;&%G<P!P97)L7W)U
M;@!097)L7VYE=UA3`%!E<FQ?<W9?<V5T<'9N`'!E<FQ?86QL;V,`4&5R;%]S
M=E]S971P=@!P97)L7V-O;G-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]S
M869E<WES;6%L;&]C`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7VUG7W-E=`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?<WES
M7VEN:70S`'!E<FQ?<&%R<V4`7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K
M-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U
M;FQI;FL`<W1R=&]K`&=E='!W=6ED`'-T<FQE;@!R;61I<@!R96%D`%]?;65M
M8W!Y7V-H:P!M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`<F5A9&QI;FL`
M<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?;65M;6]V95]C:&L`7U]F<')I;G1F
M7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`
M7U]C>&%?9FEN86QI>F4`<W1R8VAR`&]P96YD:7(`9V5T=6ED`&%C8V5S<P!M
M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`<W1R;F-M<`!?7V5N=FER
M;VX`7U]R96=I<W1E<E]A=&9O<FL`;&EB<&5R;"YS;RXU+C0P`&QI8F,N<V\N
M-@!'3$E"0U\R+C$T`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`
M1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR+C4````!``$``0`"
M``,``0`!``(`!``"``(``@`!``$``@`"``$``P`"``(``0`!``(``@`!``4`
M`@`#``$``0`!``$``0`!``(``@`!``(``@`!``(``@`!``8``@`"``4``@`!
M``$``@`"``,``@`"``$``P`!``<`"``"``(``@`"``$``@`"``````````$`
M!P`!`P``$`````````"4D98&```(``L#```0````M)&6!@``!P`6`P``$```
M`!1I:0T```8`(0,``!````"SD98&```%`"L#```0````<AEI"0``!``V`P``
M$````'09:0D```,`0@,``!````!U&FD)```"`$X#````````P,L````````(
M`````````/`I````````R,L````````(`````````+`I````````T,L`````
M```(`````````$YQ````````V,L````````(`````````.EP````````X,L`
M```````(``````````9Q````````Z,L````````(`````````%]Q````````
M"-`````````(``````````C0````````(-`````````(`````````/AR````
M````N,\````````&````!@``````````````P,\````````&````!P``````
M````````R,\````````&````%0``````````````T,\````````&````&0``
M````````````V,\````````&````/P``````````````X,\````````2````
M'@``````````````Z,\````````&````'P``````````````\,\````````&
M````(```````````````^,\````````&````.P``````````````0-``````
M```%````0@``````````````8-`````````%````0```````````````<-``
M```````%````00``````````````",X````````'`````0``````````````
M$,X````````'`````@``````````````&,X````````'`````P``````````
M````(,X````````'````!```````````````*,X````````'````!0``````
M````````,,X````````'````"```````````````.,X````````'````"0``
M````````````0,X````````'````"@``````````````2,X````````'````
M"P``````````````4,X````````'````#```````````````6,X````````'
M````#0``````````````8,X````````'````#@``````````````:,X`````
M```'````#P``````````````<,X````````'````$```````````````>,X`
M```````'````$0``````````````@,X````````'````$@``````````````
MB,X````````'````$P``````````````D,X````````'````%```````````
M````F,X````````'````%@``````````````H,X````````'````%P``````
M````````J,X````````'````&```````````````L,X````````'````&@``
M````````````N,X````````'````&P``````````````P,X````````'````
M'```````````````R,X````````'````'0``````````````T,X````````'
M````(0``````````````V,X````````'````(@``````````````X,X`````
M```'````(P``````````````Z,X````````'````)```````````````\,X`
M```````'````)0``````````````^,X````````'````)@``````````````
M`,\````````'````)P``````````````",\````````'````*```````````
M````$,\````````'````*0``````````````&,\````````'````*@``````
M````````(,\````````'````*P``````````````*,\````````'````+```
M````````````,,\````````'````+0``````````````.,\````````'````
M+@``````````````0,\````````'````+P``````````````2,\````````'
M````,```````````````4,\````````'````,0``````````````6,\`````
M```'````,@``````````````8,\````````'````,P``````````````:,\`
M```````'````-```````````````<,\````````'````-0``````````````
M>,\````````'````-@``````````````@,\````````'````-P``````````
M````B,\````````'````.```````````````D,\````````'````.0``````
M````````F,\````````'````.@``````````````H,\````````'````/```
M````````````J,\````````'````/0``````````````L,\````````'````
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;&O``!(A<!T`O_02(/$",,``````/\UTJT``/\EU*T`
M``\?0`#S#Q[Z:`````#IXO___V:0\P\>^F@!````Z=+___]FD/,/'OIH`@``
M`.G"____9I#S#Q[Z:`,```#ILO___V:0\P\>^F@$````Z:+___]FD/,/'OIH
M!0```.F2____9I#S#Q[Z:`8```#I@O___V:0\P\>^F@'````Z7+___]FD/,/
M'OIH"````.EB____9I#S#Q[Z:`D```#I4O___V:0\P\>^F@*````Z4+___]F
MD/,/'OIH"P```.DR____9I#S#Q[Z:`P```#I(O___V:0\P\>^F@-````Z1+_
M__]FD/,/'OIH#@```.D"____9I#S#Q[Z:`\```#I\O[__V:0\P\>^F@0````
MZ>+^__]FD/,/'OIH$0```.G2_O__9I#S#Q[Z:!(```#IPO[__V:0\P\>^F@3
M````Z;+^__]FD/,/'OIH%````.FB_O__9I#S#Q[Z:!4```#IDO[__V:0\P\>
M^F@6````Z8+^__]FD/,/'OIH%P```.ER_O__9I#S#Q[Z:!@```#I8O[__V:0
M\P\>^F@9````Z5+^__]FD/,/'OIH&@```.E"_O__9I#S#Q[Z:!L```#I,O[_
M_V:0\P\>^F@<````Z2+^__]FD/,/'OIH'0```.D2_O__9I#S#Q[Z:!X```#I
M`O[__V:0\P\>^F@?````Z?+]__]FD/,/'OIH(````.GB_?__9I#S#Q[Z:"$`
M``#ITOW__V:0\P\>^F@B````Z<+]__]FD/,/'OIH(P```.FR_?__9I#S#Q[Z
M:"0```#IHOW__V:0\P\>^F@E````Z9+]__]FD/,/'OIH)@```.F"_?__9I#S
M#Q[Z:"<```#I<OW__V:0\P\>^F@H````Z6+]__]FD/,/'OIH*0```.E2_?__
M9I#S#Q[Z:"H```#I0OW__V:0\P\>^F@K````Z3+]__]FD/,/'OIH+````.DB
M_?__9I#S#Q[Z:"T```#I$OW__V:0\P\>^F@N````Z0+]__]FD/,/'OIH+P``
M`.GR_/__9I#S#Q[Z:#````#IXOS__V:0\P\>^F@Q````Z=+\__]FD/,/'OIH
M,@```.G"_/__9I#S#Q[Z:#,```#ILOS__V:0\P\>^F@T````Z:+\__]FD/,/
M'OIH-0```.F2_/__9I#S#Q[Z_R4^K```9@\?1```\P\>^O\E7JH``&8/'T0`
M`/,/'OK_)5:J``!F#Q]$``#S#Q[Z_R5.J@``9@\?1```\P\>^O\E1JH``&8/
M'T0``/,/'OK_)3ZJ``!F#Q]$``#S#Q[Z_R4VJ@``9@\?1```\P\>^O\E+JH`
M`&8/'T0``/,/'OK_)2:J``!F#Q]$``#S#Q[Z_R4>J@``9@\?1```\P\>^O\E
M%JH``&8/'T0``/,/'OK_)0ZJ``!F#Q]$``#S#Q[Z_R4&J@``9@\?1```\P\>
M^O\E_JD``&8/'T0``/,/'OK_)?:I``!F#Q]$``#S#Q[Z_R7NJ0``9@\?1```
M\P\>^O\EYJD``&8/'T0``/,/'OK_)=ZI``!F#Q]$``#S#Q[Z_R76J0``9@\?
M1```\P\>^O\ESJD``&8/'T0``/,/'OK_)<:I``!F#Q]$``#S#Q[Z_R6^J0``
M9@\?1```\P\>^O\EMJD``&8/'T0``/,/'OK_):ZI``!F#Q]$``#S#Q[Z_R6F
MJ0``9@\?1```\P\>^O\EGJD``&8/'T0``/,/'OK_)9:I``!F#Q]$``#S#Q[Z
M_R6.J0``9@\?1```\P\>^O\EAJD``&8/'T0``/,/'OK_)7ZI``!F#Q]$``#S
M#Q[Z_R5VJ0``9@\?1```\P\>^O\E;JD``&8/'T0``/,/'OK_)6:I``!F#Q]$
M``#S#Q[Z_R5>J0``9@\?1```\P\>^O\E5JD``&8/'T0``/,/'OK_)4ZI``!F
M#Q]$``#S#Q[Z_R5&J0``9@\?1```\P\>^O\E/JD``&8/'T0``/,/'OK_)3:I
M``!F#Q]$``#S#Q[Z_R4NJ0``9@\?1```\P\>^O\E)JD``&8/'T0``/,/'OK_
M)1ZI``!F#Q]$``#S#Q[Z_R46J0``9@\?1```\P\>^O\E#JD``&8/'T0``/,/
M'OK_)0:I``!F#Q]$``#S#Q[Z_R7^J```9@\?1```\P\>^O\E]J@``&8/'T0`
M`/,/'OK_)>ZH``!F#Q]$``#S#Q[Z_R7FJ```9@\?1```\P\>^O\EWJ@``&8/
M'T0``/,/'OK_)=:H``!F#Q]$``#S#Q[Z_R7.J```9@\?1```\P\>^O\EQJ@`
M`&8/'T0``/,/'OK_);ZH``!F#Q]$``#S#Q[Z_R6VJ```9@\?1```\P\>^E53
M2(/L.(E\)!Q(C7PD'$B)="002(UT)!!(B50D"&1(BQ0E*````$B)5"0H2(U4
M)`CHAO___TB+-7>H``!(BSVHJ```2(GRZ"`[``"`/1FI````#X0;`0``2(L%
M?*@``&1(BP"`B#H$```#BT0D'(UX!(U8`TAC_TC!YP/HN_[__TB+?"001(M$
M)!Q(B<%(B07OJ```2(L'2(D!2(T%04H``$B)00A(BP5OJ```2(E!$$B-!2Y*
M``!(B4$808/X`0^.*0$``$B#QPA!@\`#N@0```!F#Q^$``````!(BP=(8_*#
MP@%(@\<(2(D$\40YPG7J2&/22(L]D*@``$4QP$B--18(``!(QP31`````(G:
MZ*?[__^%P`^$AP```$B+/6BH``!(C6PD).AN_?__2(GN2(T]9T@``(G#,<#H
MNP$``$B%P'1O2(L]/Z@``.A*^___Z,7\__](BT0D*&1(*P0E*`````^%F```
M`$B#Q#B)V%M=P^A#_/__2(D%#*@``$B)QTB%P'1QZ*_\__](BP5(IP``9$B+
M$,:"M@@```#IO/[__TB+/>&G``#HC/O__^EH____2(L]P*<``$B%_W0*Z-8=
M``#I>____TB-/8)'``!(B>[H(@$``$B)!9NG``!(B<=(A<`/A%G____KTKH$
M````Z?G^__^_`0```.CI^O__Z-3\__\/'T``\P\>^C'M28G17DB)XDB#Y/!0
M5$4QP#')2(T]T?W___\5PZ8``/1F+@\?A```````2(T]X:8``$B-!=JF``!(
M.?AT%4B+!6ZF``!(A<!T"?_@#Q^``````,,/'X``````2(T]L:8``$B--:JF
M``!(*?Y(B?!(P>X_2,'X`T@!QDC1_G042(L%-:8``$B%P'0(_^!F#Q]$``##
M#Q^``````/,/'OJ`/;:F````=2M52(,]$J8```!(B>5T#$B+/3:F``#HN?G_
M_^AD____Q@6.I@```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````05=!
M5D%505154TB#[`A,BS4KI@``387V#X24````#[8'28G_28GUA,!T!#P]=5%%
M,>1)BQY(A=MT+$UCY$R)]4R)XDR)_DB)W^C2^?__A<!U!T*`/",]=$=(BUT(
M2(/%"$B%VW7:2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q!#[9$)`%)
M@\0!A,!T!#P]=>Y%*?SKF&8/'T0``$PI]4J-7",!2,']`T&);0#KM#';Z[!F
M+@\?A```````4TB![*````!D2(L<)2@```!(B9PDF````$B)^TB)YN@L^___
MA<!U.(M4)!B!X@#P``"!^@!```!T"('Z`*```'4@O@(```!(B=_H<?O__X7`
M#Y3`#[;`ZPD/'X``````,<!(BY0DF````&1(*Q0E*````'4)2('$H````%O#
MZ)WZ__]F9BX/'X0``````&:0059!54%455-(@>R@````9$B+!"4H````2(F$
M))@````QP$B%_W0(@#\`2(G[=3%(BX0DF````&1(*P0E*`````^%&0$``$B!
MQ*````!;74%<05U!7L-F+@\?A```````Z$OY__])B<1(A<!TPDR)Y^@;^___
M2(7`#X2B````@'@3+DB-:!-U"(!]`0!TWV:0@'@3+@^$G@```$B)W^CN^/__
M2(GO28G%Z./X__]%C70%`DUC]DR)]^@C^/__28GI28G83(GR28G%2(G'O@(`
M```QP$B-#=I#``#H0?K__TR)[TB)YNBV^/__3(GO@_C_=!"+1"08)0#P```]
M`$```'16Z`GX__],B>_H<?C__TR)Y^AY^O__2(7`#X5>____3(GGZ.CY__](
MB=_H\/?__^GZ_O__#Q\`@'T!+@^%6/___X!]`@`/A"'____I2?___P\?@```
M``#HH_[__^NHZ"SY__]F9BX/'X0``````)!!5S'`059!54%455-(B?M(@^PH
M@#X]9$B++"4H````2(EL)!A(B?4/E,!(`<5(B>_HZ_?__TB-="042(G?28G$
M,<#H^?S__TB%P`^$*`$``$B)QTF)Q>C%]___3#G@#X/T````3&-$)!1.C33%
M``````^V`X3`#X3D`0``/#T/A-P!``!(B=AF9BX/'X0``````&9F+@\?A```
M````#Q\`#[90`4B#P`&$TG0%@/H]=>](*=A(F$R++<.B``!*C7P@`NBI]O__
M30'U28E%`$B%P'1>2(L%IJ(``$B-2P%*BQ0P#[8#B`(\/70JA,!U%>LD9F8N
M#Q^$```````/'T``/#UT$0^V`4B#P@%(@\$!B`*$P'7KQ@(],<!F#Q]$```/
MMDP%`(A,`@%(@\`!A,EU[TB+1"089$@K!"4H````#X4O`0``2(/$*%M=05Q!
M74%>05_##Q]``#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[T/'T``3(L]
M`:(``$F#/P`/A-X```!,B?A%,>UF9BX/'X0``````&8/'T0``$B#P`A$B>I!
M@\4!2(,X`'7O1(UR`TUC]DJ-#/4`````BP7RH0``A<!U9DB)STB)3"0(QP7<
MH0```0```.B/]?__2(G'2(7`#X1$____36/%2(M,)`A,B?Y.C33%`````$R)
M\NCH]___2(D%<:$``$B)QT&-10%$B6PD%$B82,<$QP````#I1_[__V8/'T0`
M`$R)_TB)SNB5]___2(D%/J$``$B)QTB%P`^$X_[__TUCQ4Z--,4`````Z[</
M'T0``#'`Z4_^__^Y$````$4Q[>E,____Z*?V__\/'X``````055!5%532('L
M`!```$B##"0`2(/L&+K_#P``9$B++"4H````2(FL)`@0``!(B?5(B?M(B>9(
MC3V.0```Z/_U__^%P'X5B<&#Z`%)B>1(8]"`/!0`=4J%P'4W2(L%/Z```$B)
MZDB)WF1(BSCHT/3__TB+A"0($```9$@K!"4H````=5!(@<08$```6UU!7$%=
MPXG!9F8N#Q^$``````!FD$QCZ;XO````3(GG3(GJZ-WS__](A<!THDB+!>&?
M``!,B>E,B>)(B=YD2(LXZ%_U___KG>C(]?__#Q^$``````#S#Q[Z4TB+';2?
M``!(C0T]@```2(TUWS\``$B+%:>?``!D2(L[Z%;V__]D2(L[13')6TR-!6M!
M``!(C14@%```3(G!2(TURS\``.G!]/__D/,/'OI(BP5EGP``2(L59I\``$B-
M#>=_``!(C36)/P``9$B+..D']O__#Q^``````/,/'OI!5%532('L`!```$B#
M#"0`2('L`!```$B##"0`2(/L(&1(BP0E*````$B)A"08(```,<!(C:PD$!``
M`.B\\___3(T-*C\``+H!$```2(GG08G`2(T-33\``+X"````,<#H9_7__TB)
MY[H`$```2(GNZ&?T__\Q_X7`>#)$C6`!2(G#36/D3(GGZ/_R__](B<=(A<!T
M&$ACVTR)X4B)[DB)VNA&\___Q@08`$B)QTB+A"08(```9$@K!"4H````=0](
M@<0@(```2(GX6UU!7,/H:/3__P\?A```````\P\>^ND7____#Q^``````/,/
M'OI!5T%6055!5%532('L`!```$B##"0`2('LN````&1(BP0E*````$B)A"2H
M$```,<!)B?Q(B?-(C3V'/@``2(UT)`SH)?C__[XO````3(GG2(G%Z*7S__](
MA<!T0#'`3(GF2(T]93X``.B_^O__3(G@2(N4)*@0``!D2"L4)2@````/A8(!
M``!(@<2X$```6UU!7$%=05Y!7\,/'P!(B=],C2TT/@``3(TU,S\``.AZ\___
M3(GN2(G'Z*_S__](B<-(A<!TEX`[``^$Y````&9F+@\?A```````#Q\`2(7M
M=!-(B=Y(B>_H<//__X7`#X2?````2(G?Z%#R__](C50#_TF)QT@YTW(/ZQV0
MQ@(`2(/J`4@YTW0%@#HO=.](B=_H)_+__TF)QTR)Y^@<\O__28U$!P%(/?\/
M```/AQO___],C;PDH````$R)\4F)V#'`2(/L"+H`$```O@(```!,B?]!5$R-
M#7$]``#H;//__TB-="0@3(G_Z-_Q__]:687`=1"+1"0H)0#P```]`(```'1)
M3(GN,?_HS_+__TB)PTB%P`^$L_[__X`[``^%*O___TB%[70&@'T`+G070;\!
M````2(T=^#P``.E9____#Q]$``"`?0$`=+GKX;X!````3(G_Z`/S__^%P'6F
M3(G^2(T]UCP``.@P^?__3(G_Z"CR___I9_[__^@^\O__9F8N#Q^$```````/
M'P#S#Q[Z4[XO````2(G[Z([Q__](C5`!2(7`2`]%VDB)WUOIZO'__V8N#Q^$
M``````#S#Q[Z55-(@>P`$```2(,,)`!(@^P89$B+!"4H````2(F$)`@0```Q
MP$B%_P^$W@```(`_`$B)^P^$T@```.B]\/__2(U0`4B!^@`0```/A_0```!(
MB>5(B>>#^@AR#HG12(G>P>D#\TBE2(GS,<GVP@1T"8L+B0^Y!````/;"`G0.
M1`^W!`MF1(D$#TB#P0*#X@%T!P^V%`N(%`](C40%_T@YQ7(FZREF9BX/'X0`
M`````&9F+@\?A```````9I#&``!(@^@!2#GH=`6`."]T[[XO````2(GOZ)+P
M__](A<!T+4@YQ7)82(GOZ/#P__](BY0D"!```&1(*Q0E*````'5)2('$&!``
M`%M=PP\?`$B+A"0($```9$@K!"4H````=2E(@<08$```2(T]13L``%M=Z:CP
M__\/'X0``````,8``.NC#Q\`,<#KI.BO\/__9F8N#Q^$```````/'T``\P\>
M^D%7059!54%454B-+1X[``!32(/L&&1(BQPE*````$B)7"0(2(U<)`0/'T``
M,<!(B=Y(B>_H@_3__TB%P'0V2&-4)`1(BP6RF@``2(T$T$B+4`A(B1!(A=)T
MTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(TMO#H``)`QP$B)WDB)[^@S
M]/__2(7`=#9(8U0D!$B+!6*:``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!(C2UT.@``D#'`2(G>2(GOZ./S__](A<!T-DAC
M5"0$2(L%$IH``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#K
MOF8/'T0``$B-+2TZ``"0,<!(B=Y(B>_HD_/__TB%P'0V2&-4)`1(BP7"F0``
M2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(TM
MY#D``)`QP$B)WDB)[^A#\___2(7`=#9(8U0D!$B+!7*9``!(C0302(M0"$B)
M$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C26D.0``D#'`2(G>
M3(GGZ//R__](A<!T-DAC5"0$2(L%(ID``$B-!-!(BU`(2(D02(72=-)FD$B+
M4!!(@\`(2(D02(72=?#KOF8/'T0``$R-)0DY``"0,<!(B=Y,B>?HH_+__TB%
MP'0V2&-4)`1(BP72F```2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```3(TU$#D``)`QP$B)WDR)]^A3\O__2(7`=#9(8U0D!$B+
M!8*8``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$
M``!,C2W*.```D#'`2(G>3(GOZ`/R__](A<!T-DAC5"0$2(L%,I@``$B-!-!(
MBU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-/80X``"0
M,<!(B=Y,B?_HL_'__TB%P'0V2&-4)`1(BP7BEP``2(T$T$B+4`A(B1!(A=)T
MTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(T]TC<``)`QP$B)WDR)_^AC
M\?__2(7`=#9(8U0D!$B+!9*7``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!(B=Y(C3WK-P``Z!GQ__](A<!T#4B)QDR)[S'`
MZ,?S__\QP$B)WDB-/=DW``#H]O#__TB%P'012(G&2(T]US<``#'`Z*#S__](
MB=Y(C3W1-P``,<#HS_#__TB)QDB%P'0Y3(GG,<#H??/__TB+1"0(9$@K!"4H
M````=41(@\082(GO2(TUNS<``#'`6UU!7$%=05Y!7^E.\___,<!(B=Y(C3V-
M-P``Z'WP__](A<!TNTB)QDR)]S'`Z"OS___KK.A$[/__#Q]``/,/'OI(@^P8
M2(T]`#<``&1(BP0E*````$B)1"0(,<!(C70D!.@W\/__2(7`=#(/MA"`^C`/
ME,"$T@^4P@G0@_`!#[;`2(M4)`AD2"L4)2@```!U$$B#Q!C##Q^``````#'`
MZ^#HU^O__P\?@`````#S#Q[Z4%A(@>S8````2(ET)"A(B50D,$B)3"0X3(E$
M)$!,B4PD2(3`=#</*40D4`\I3"1@#RE4)'`/*9PD@`````\II"20````#RFL
M)*`````/*;0DL`````\IO"3`````9$B+!"4H````2(E$)!@QP$B)^DB-A"3@
M````2(GA2(L]RI4``$B)1"0(O@(```!(C40D(,<$)`@```#'1"0$,````$B)
M1"00Z%+J__^__P```.@HZ?__#Q^$``````!!5%533(V<)```__](@>P`$```
M2(,,)`!,.=QU[TB#[!"Z`@```#'V9$R+)"4H````3(FD)`@``0!!B?Q(B>/H
M/.O__TB-:/](B>I(P?H_2,'J,$B-1!4`#[?`2"G02"G%#XB]````9@\?A```
M````,=)(B>Y$B>?H`^O__TB#^/\/A+0```"Z"``!`$B)WD2)Y^BIZ/__@_C_
M#X2-````2)A(@_@'=FA(C40#^$@YV')>2(T5AY0``.L>9F8N#Q^$``````!F
M+@\?A```````2(/H`4@YV'(W2(L(2#D*=>](*=A(`>A(BY0D"``!`&1(*Q0E
M*````'5/2('$$``!`%M=05S#9BX/'X0``````$B![0```0!(@?T``/__#X5,
M____2,?`_____^NZ2(T])S4``#'`Z`7^__](C3T,-0``,<#H]_W__^C"Z?__
M9I#S#Q[Z2(/L".CSZ?__B<?H?.C__TB%P'0#2(L`2(/$",-F9BX/'X0`````
M``\?0`#S#Q[Z059!54%43(TEUC0``%5(B?U,B>=32(/L$&1(BP0E*````$B)
M1"0(,<!(C70D!.AY[?__2(7`=`B`.`!(B<-U+$B+1"0(9$@K!"4H````=7Y(
MB>Y(@\003(GG,<!;74%<05U!7ND#\/__#Q\`2(GOZ!CH__](B=])B<7H#>C_
M_TV-=`4"3(GWZ%#G__](@^P(3(GR28GH4TB)QTF)Q4R-#78S``!(C0UU-```
MO@(````QP.AEZ?__6%I(BT0D"&1(*P0E*````'4%3(GNZX7HN>C__V8/'X0`
M`````/,/'OI!5T%6055!5%532('L>`$``/,/?@6#C@``2(D\)$B-;"0<2(T]
M^S(``$B)[F1(BP0E*````$B)A"1H`0``2(T%WC(``$C'1"0P`````$C'A"2(
M`````````$C'1"10`````&9(#V[(2(T%L3,``&8/;,%F2`]NT$B-!:DS```/
M*40D(&9(#V[8\P]^!12.``!(C069,P``9D@/;N`QP&8/;,(/$40D:/,/?@7]
MC0``9@]LPP\11"1X\P]^!?2-``!F#VS$#RE$)$#H_NO__TB%P'0,@#@`2(G#
M#X7-!```Z`CH__^)Q^B1YO__2(7`#X0(!```3(LX387_#X3\`P``3(G_Z*3F
M__],C70``4R)]TV)].CDY?__10^V!TB)1"0(2(G#183`=&!,C2T),P``9F8N
M#Q^$``````"03(GR10^VP$B)WS'`3(GIO@(```!)@\<!Z./G__]-.?1,B?)%
M#[8'20]#U$B)T$PI\$B#P`)(.=!(#T+"22G62(/#`DV-=`;^183`=;-,C6PD
M8$B-/2<R``#K$@\?1```28M]"$F#Q0A(A?]T,TB)[C'`Z!GK__])B<1(A<!T
MX8`X`'3<2(G'Z,3K__^%P'303(GGZ+CF__])B<1(A<!U-DR-;"0@38ME`$V%
MY'0H08`\)``/A/\"``!,B>?HC^O__X7`#X4'`0``38ME"$F#Q0A-A>1UV$R)
MY^B2Y?__2(M<)`A)B<5(B=_H@N7__T6-M`4$!```36/V3(GWZ+_D__]338G@
M3(T-]#```$F)Q4B-!?4Q``!,B?*^`@```%!(C0W<,0``3(GO,<#HT.;__TR)
M[[[``0``Z$/G__]?05B#^/]U$NCVY?__1(L(08/Y$0^%[P(``$B-M"20````
M3(GOZ#GF__^)PX7`#X1_````2(L$)$V)Z$B+/7&0``!(C14Z,@``O@(```!(
MBP@QP.C;X___13'D#Q^$``````!(BX0D:`$``&1(*P0E*`````^%/`0``$B!
MQ'@!``!,B>!;74%<05U!7D%?PP\?0`!,B>=)@\4(Z'3E__])B<1(A<`/A+W^
M___IZ?[__P\?`(N$)*@````E`/```#T`0```#X5J____1(ND)*P```#HG.7_
M_T$YQ`^%5/___XN$)*@````E_P$``#W``0``#X4]____3(GWZ(3C__](B>Y(
MC3V,,```28G$,<#H0.G__TB%P`^$5P(``$B+#"1(B<9(BSGHN/#__TF)QTB%
MP`^$/`(``$R)_^CTX___2(G"@_@#?CQ(F$B--8,P``!(B50D"$F-?`?\Z.3D
M__^%P'4@2(M4)`B#^@0/A/H"``"-0OM(F$&`/`<O#X3J`@``9I!(B>Y(C2UU
M+P``,<!(B>_HO.C__TB%P`^$XP$```^V`(3`#X38`0``/#`/A-`!``!(B>](
MC36R+P``,<#H3^O__TB-+4PP``!,C3TS,```Z!SC__]53(GR3(T-X2X``%!-
MB>A(C0T*,```O@(```!,B><QP.C'Y/__6%KK/P\?`.C[X___@S@1=43HX>+_
M_X/#`4B#[`A-B>A53(T-GRX``$R)^4R)\E.^`@```$R)YU`QP.B(Y/__2(/$
M(+[``0``3(GGZ/?D__^#^/]TLDR)[^C*XO__3(GF2(T]2"X``#'`Z*GJ__],
MB>?H,?K__^GL_?__#Q]``$4QY.D6_?__2(U<)$!F9BX/'X0``````$B+.TB%
M_W0D2(GN,<#HKN?__TB)QTB%P'0%@#@`=4%(BWL(2(/#"$B%_W7<OPT```!!
MO`T```!,C3W)+@``0;X-````Z*?A__]!N%,```!(B40D"$B)P^G!^___#Q]`
M`.@;X___2(/#"$F)QTB%P'2/Z7[[__](BP0D38GH2(L]G(T``$B-%24O``"^
M`@```$B+"#'`Z`;A___I)OW__Y!(B<?H:/G__TB+A"1H`0``9$@K!"4H````
M#X5D`0``2('$>`$``$B)WUM=05Q!74%>05_IJ.+__P\?A```````2(L$)$R+
M..FX_?__#Q]``$R)_S'V,<#H).+__T&)QX7`#X09_O__B<?H@O?__TB%P`^(
M"?[__S'22(UP]D2)_TB)!"3HY^+__TB-M"0J`0``N@8```!$B?_HDN#__TB+
M#"1(@_@&#X7<````@;PD*@$```!#04,/A</]__]F@;PD+@$``$A%#X6S_?__
M,=)(C7'.1(G_Z)7B__](C9PD,`$``+HH````1(G_2(G>Z#W@__](@_@H#X6+
M````2(T%X"T``+X"````38GH3(GRQH0D6`$```!(C0V7+0``3(T-:RP``$R)
MYU`QP%/H7^+__UE>Z>;]__](BP0D2(M0"$B%T@^$!_W__TB)UTB)%"3HJ^#_
M_TB#^`,/AO'\__](BQ0D2(TU.RT``$B-?`+\Z)SA__](BQ0DA<!,#T3ZZ<W\
M___H>.'__TB-/1LM```QP.B:]?__9BX/'X0``````/,/'OI!5$B-/08L``!5
M4TB#[!!D2(L<)2@```!(B5PD"$B+'3B+``!,C60D!$R)YF1(BRL/MH6P````
MB(6Q````,<#H..7__TB%P'0)@#@Q#X1J`0``,<#H8_#__V1(BRM(B>^Y`P``
M`+H!````2(TUSBP``.A6W___2(G%2(7`="A(BT`09$B+.TB-%;0L``!(BS#H
M9]___TB+11!(BS#V1@Y`#X4^`0``9$B+.[D#````N@$```!(C36++```Z`S?
M__](B<5(A<!T,$B-/0XK``!,B>8QP.BCY/__2(G"2(M%$$B+.$B%T@^$X```
M`$B)_F1(BSOH!-___V1(BSNZ`0```$B--4`L``#H'][__V1(BSM(C15%+```
M2(G&Z-S>__]D2(L#3(GF2(T]IBH``,:`L0`````QP.A`Y/__2(D%N8H``$B)
MPTB%P'1!OL`!``!(B=_H%.'__XU0`8/Z`78)@_@1#X6)````2(M$)`AD2"L$
M)2@````/A9(```!(@\006UU!7,-F#Q]$``!(BSUQB@``Z!3W__](B05=B@``
M2(G#2(7`=:1(C3U6+```,<#H]]___P\?@`````"`>`$`#X27_O__Z8?^__^0
M2(L5,8H``$B+,NCAZ/__Z1C___\/'T``9$B+.^A?W___Z;3^__^)P4B+!0F*
M``!(B=I(C3TG+```2(LP,<#HG=___^A(W___#Q^$``````#S#Q[Z55-(B?M(
MC3W_*0``2(/L&&1(BP0E*````$B)1"0(,<!(C70D!.@RX___2(7`=!P/MA"$
MT@^4P(#Z,`^4P@C0=0I(A=MT!8`[`'4A2(M$)`AD2"L$)2@```!U<DB#Q!A;
M7<-F+@\?A```````2(G?Z,CL__^^+P```$B)QTB)Q>@HWO__2(U0`4B%P$@/
M1>I(B>_HA=[__[H$````2(TU-"H``$B)Q^C1W/__A<!UG$B+1"0(9$@K!"4H
M````=0Y(@\082(G?6UWIW^/__^AJWO__9BX/'X0``````$%7059!54%455-(
M@>R8`@``9$B+-"4H````2(FT)(@"``!(B?Y(B>),C8PD@````$B)YTR-1CAF
M#Q^$``````!!BP!-BQ!(@\<028/`"`_(B<!,B=%(B4?P3(G02,'I($C!Z"A)
MP>HX)0#_``!,"=!)B<I(P>$(2<'B&('A``#_`$6)TDP)T$@)R$B)1_A,.<]U
MK;O_____9@]O1"002(U$)&AF#V]<)"!F2`]NZV8/;U0D,$B!PF@"``!F#VSM
MD/,/;PAF#V_B9@]O4-A(@\`09@_O0(AF#^_*9@_OP68/;\AF#W/P`68/<]$?
M9@_KP68/V\4/*4`(9@]OPV8/;]Q(.=!UNTR+#DR+7A!(BWX@2(M>&$R)R$R)
MRDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D2(V,"YEY@EJ-E#B9>8):3(G82#'8
M2"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)B?I("<),B=A)P>H;08G03#'`3"'(
M3#'82`'(2(GY2,'A!4P)T4R+5"001(TD"$R)R$R)R4C!Z0)(P>`>3XV4$YEY
M@EI-B>5("<A)P>T;2#'"B<%((?I,,<),`=)-B>))P>(%30GJ3(ML)!A!`=)(
MB?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'0B==,(>!)P>T;2#'(3`'`
M38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)
MQ4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI3(ML)"@!T4R)TDG!Z@)(
MP>(>B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(B<](P><%
M3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!
MB<!((<I,,=),`>))B?Q)P>0%30GL3(ML)#A!`=1(B<I(P>D"2,'B'D6)Y$^-
ME"J9>8):2`G*38GE2#'02<'M&XG12"'X3#'`3`'038GB2<'B!4T)ZDR+;"1`
M00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"6D@)^$V)U4@QPDG![1N)QTPAXD@Q
MRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)XDG![`)(P>(>18G`2HV,*9EY@EI,
M">)-B<5(,=!)P>T;08G43"'02#'X2`'(3(G!2,'A!4P)Z4R+;"10`<%,B=!)
MP>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(,<))P>T;08G"3"'"3#'B2`'Z2(G/
M2,'G!4P)[TR+;"18`==,B<))P>@"2,'B'HG_3XVD+)EY@EI,"<))B?U(,=!)
MP>T;08G02"'(3#'03`'@28G\2<'D!4T)[$R+;"1@00'$2(G(2,'@'DC!Z0)%
MB>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)P4@A^DPQPDP!TDV)XDG!X@5-">I,
MBVPD:$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=!)P>T;B==,
M(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9
M>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD>`'1
M3(G22,'B'DG!Z@*)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!
M^$B)STC!YP5,">],BZPD@`````''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`
M28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q&C2PB2(G*2,'I`DR+
MI"2(````2,'B'D@)RD^-E"*9>8):38GL2#'02<'L&XG12"'X3#'`3`'038GJ
M2<'B!4T)XDR+I"20````00'"2(GX2,'@'DC![P)%B=)/C80@F7F"6D@)^$V)
MU$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!X`5-">!%B<!,`<)-B>A)P>T"2<'@
M'D&)U$T)Z$R+K"28````3#'`3"'02HV,*9EY@EI-B>5(,?A)P>T;2`'(3(GA
M2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!B<5,"=%-B<)%B<!),<I$,=),BY0D
MH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J&TC!X@5,"=*)TD@!UTR)XDC!XAY)
MP>P"08GZ3`.$)*@```!,">))B<R)R4@#C"2P````23'41#'@38VD`*'KV6Y,
MB=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH2<'M`DC!X!Y%B>!,">A)B=6)TD@#
ME"2X````23'%1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G1
M2<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!
MX@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(2`.$),````")R4DQT$@#
MC"3(````13'H3HVL`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'%2(GX2,'O
M`DC!X!Y%B>A("?A(B=>)TD@#E"30````2#''1#'G3(VD.:'KV6Y,B<%,B<=(
MP>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"38````
M23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!
MXAY%B>I,"<))B<B)R4DQT$@#C"3@````13'@3HVD`*'KV6Y,B=!-B=!)P>@;
M2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"3H````2#''
M1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$
MB>],"=%)B<*)P$@#A"3P````23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B
M!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN
M3(G038G02,'@!4G!Z!M(`XPD^````$P)P(G`20'%2(GX2,'O`DC!X!Y%B>A(
M"?A(B=>)TD@#E"0``0``2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;2,'A!4@)
M^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"0(`0``23'*13'J3HVL
M$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%B>I,"<))
MB<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<!(`XPD$`$``(G`
M20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"08`0``2#''1#'O3(VL.:'K
MV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)
MP$@#A"0@`0``23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'4
M3(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G038G02<'H
M&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"18GH2`.,)"@!``!("?A(B=>)TD@#
ME"0P`0``2#''1#'G38G$2(V,.:'KV6Y,B<=)P>P;2,'G!4P)YTV)U$G!Z@))
MP>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$)#@!``!%,>I)B?U.C902H>O9;DB)
M^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!XAY%B=),"<)-B>!%B>1),=!)B=9!
MB=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(P>`%3`G`1(T$`4B)^4C![P*XW+P;
MCTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+E"1``0``2`'"3`'B38G$3`'R38G&
M2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPA
MP4P)\4R+M"1(`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,
MB<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"10`0``20'&3`'W
M38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!
MB=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR
M28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0D8`$`
M`$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;30GP00'02(GZ2,'O`DC!XAY%B<!(
M"?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H`0``20'&30'T38G&3`'A38G$2<'N
M&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4&)RDD)SDTAQDPATDP)
M\DR+M"1P`0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<)(P>(>
M2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPAX4P)\4R+M"1X`0``20'&3`'W38GN
M2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)X4G![`)(P>$>B?],">%!B<Q)"<Y-
M(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)_DP!TDF)^DG![AM)P>(%30GR00'2
M3(GJ2<'M`DC!XAY%B=),">I("=%)B=9!B=5((?E-(>9,"?%,B[0DB`$``$D!
MQDT!\$V)UDP!P4V)T$G![AM)P>`%30GP28G600'(2(GY2,'O`DC!X1Y%B<!(
M"?F)STD)SDTAUD@A^DP)\DR+M"20`0``20'&30'T38G&3`'B38G$2<'N&TG!
MY`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPAP4P)\4R+
MM"28`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,B<%)P>@"
M2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"2@`0``20'&3`'W38GN2`'Z
M3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!B=1-(<9,
M(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR28G600'*
M3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0DL`$``$D!QDT!
M\$V)UDP!PDV)T$G![AM)P>`%30GP00'02(GZ2,'O`DC!XAY%B<!("?I("=%)
MB=:)UTTA[DPAT4P)\4R+M"2X`0``20'&30'T38G&3`'A38G$2<'N&TG!Y`5-
M"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4D)SD&)RDTAQDPATDP)\DR+M"3`
M`0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<))P>@"2,'B'D6)
M[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(`0``20'`3`''38GH2`'Y3(GO
M2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)T4C!YQY,">=!B?Q("?E,(>E,(>)(
M"<I(BXPDT`$``$@!P4P!T4V)PD@#A"38`0``2`'*3(G!2<'J&TC!X05,"=&)
MR4@!RDR)Z4G![0)(P>$>08G23`GI2`G/28G-08G.3"''32'E20G]2HT\.$R)
MT$R+O"3X`0``3`'O38G52,'@!4G![1M,">B)P$@!QTR)P$G!Z`)(P>`>08G]
M20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"3`'B38GL2`'*3(GI2<'L&TC!X05,
M">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB38G$B=%%B<!-,=1$,>=,BZ0DZ`$`
M`$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%30GT38GN2<'M`DG!YAY%B>1-"?5,
MB[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ[D0Q\DV)YDD!T$R)XDG![AM(P>(%
M3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)RD2)T4V)ZDDQTDP!^4R+O"0``@``
M1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ
M20G,1(GI28G5B=)-,>5,`?E,B[PD$`(``$4QZ$V)U4D!R$R)T4G![1M)`<=(
MP>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"0(`@``20'&3`'R38GF
M23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^
M20G21(GB28G,B<E,`?I-,=1,B[PD(`(``$4QX$V)]$D!T$R)\DG![!M)`<=(
MP>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)ZDR+K"08`@``20'%3`'I38G5
M23'51#'O38GE2`'/3(GA2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]
M20G.1(G128G2B=)-,?),`?E,B[PD,`(``$4QT$V)ZDD!R$R)Z4G!ZAM(P>$%
M3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!QTP)X4R+I"0H`@``20'$3`'B38GT
M23',1#'G38G42`'73(G22<'L&TC!X@5,">*)TD@!UTR)ZDG![0)(P>(>08G\
M20G51(GR28G.B<E-,>Y,`?I,B[PD0`(``$4Q\$V)YDD!T$R)XDG![AM(P>(%
M3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)TDR+E"0X`@``20'"3`'138GJ23'2
M1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(P>$>08GZ
M20G,1(GI28G5B=)-,>5,`?E,B[PD8`(``$4QZ$V)U4D!R$R)T4G![1M(P>$%
M3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"1(`@``20'&3`'R38GF18GD
M23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(P>(>08G^
M20G22(N4)%`"``!(`<))`=1(B<J)R4PQTDD!QT0QPDV)\$D!U$R)\DG!Z!M(
MP>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)X$P)ZDR+K"18`@``20'%3`'I38G5
M23'51#'O38G%2`'/3(G!2<'M&TC!X05,">F)R4@!STR)\4G![@)(P>$>08G]
M20G.1(G128G2B=)-,?),`?E,B[PD<`(``$4QXDV)[$P!T4V)ZDG![!M)P>(%
M30GB38G$18G22<'D'DP!T4G!Z`))`<=-">!,BZ0D:`(``$&)RDD!Q$@#A"1X
M`@``3`'B38GT3`'(33'$1#'G38G42`'73(G22<'L&TC!X@5,">)-B>Q)P>T"
M2<'D'HG230GE18GT38G&2`'733'NB?I-`?Q%B<!$,?%)B=9,`<!-B>A,`>%)
MB=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))P>0>B<E-">)-,=!$,<=)B<A(`?A(
MB<](P><%2<'H&P'I00':3`G'1`-N($B)3@@!^$R)5AA(B09(B=!(P>H"2,'@
M'DR);B!("=!$`=A(B4802(N$)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<
M05U!7D%?P^CVQ___9@\?1```\P\>^DB#[`B_@````.@NQO__9@]O!792``!(
MQT`P``````\1`&8/;P5S4@``QT!X``````\10!!F#V\%<%(```\10"!(@\0(
MPP\?@`````#S#Q[Z05=(8\))B?]!5DR-=SA!54F)]4%428G$55-(@^P82(MW
M*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(B4<P2&-'>(7`#X4A`0``08/\
M/WY^1(GE3(GKP>T&C47_2,'E!HE$)`1,`>U(B40D"&9F+@\?A```````#Q]`
M`/,/;P-,B?](@\-`00\1!O,/;T/000\11A#S#V]#X$$/$48@\P]O0_!!#Q%&
M,.B.Z/__2#GK=<F+1"0$]]C!X`9%C60$P$B+1"0(2,'@!DV-;`5`26/$2(/X
M"')L28M5`$F-=T!,B?%(@^;X28E7.$F+5`7X2"GQ22G-28E4!OA(`<A(@^#X
M2(/X"'(D2(/@^#'228M,%0!(B0P62(/""$@YPG+N9F8N#Q^$``````"018EG
M>$B#Q!A;74%<05U!7D%?PP\?1```J`1U9DB%P'3?00^V50!!B%<XJ`)TTD$/
MMU0%_F9!B50&_NO$#Q]``+U`````28T\!DR)[BG%1#GE00]/[$ACW4B)VN@`
MQ___08M'>`'H08E'>(/X0'653(G_02GL20'=Z)/G___IG?[__T&+50!!B5<X
M08M4!?Q!B50&_.EG____#Q^``````/,/'OI!5DR-=CA!54%454B)_5-,BVXH
M2(GS3(MF,$R)Z$C!Z`.#X#^-2`'&1`8X@$ACP4P!\(/Y.`^.@0$``+I`````
M*<IT#S')B<Z#P0'&!#``.=%R\TB)W^@1Y___9@_OP`\10SA)QT8P`````$$/
M$48000\11B!,B>)!#[;%38GH3(GO2,'J&$C!X`A,B>%)P>@028G13(GJ2,'O
M&`^V]DR)XDC!Z1!("?!!#[;P#[;)2,'@"$@)\$`/MO=(B=](P>`(2`GP00^V
M]$C!X`A("?`/MO9!#[;12,'@"$@)\$C!X`A("<A(P>`(2`G02(E#<.AXYO__
M2(L#2(G?2,'H&(A%`$B+`TC!Z!"(10%(BP.(90)(BP.(10-(BT,(2,'H&(A%
M!$B+0PA(P>@0B$4%2(M#"(AE!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0
MB$4)2(M#$(AE"DB+0Q"(10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&(AE
M#DB+0QB(10](BT,@2,'H&(A%$$B+0R!(P>@0B$412(M#((AE$DB+0R"(11-;
M74%<05U!7ND(P___#Q^$``````"Z.````#'V*<J#^@AS*O;"!'5MA=(/A)[^
M___&``#VP@(/A)+^__\QR6:)3!#^Z8;^__\/'T0``(G12,<``````$C'1`CX
M`````$B-2`A(@^'X2"G(`<*#XOB#^@@/@E;^__^#XO@QP(G'@\`(2(DT.3G0
M<O/I/_[__V8/'T0``,<``````,=$$/P`````Z2;^__]F+@\?A```````#Q\`
M\P\>^DB+#8UM``#I@,'___,/'OI(@^P(2(/$",,`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%53
M15(`55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@!S:&]R
M="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V,P`M
M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````
M``````$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````
M``````````$;`SL$`0``'P```'!O__\X`0``X'+__V`!``#P<O__>`$``%!V
M__]4!@``8'C__R`!``!0>?__D`$``!!Z___<`0``H'K__P`"```0?/__1`(`
M`)!^__^0`@``<'___]`"``#`?___[`(``/!___\``P``T(#__SP#``#@@/__
M4`,```"#__^T`P``,(/__]`#``"0A/__#`0``/"(__]8!```8(G__W0$```@
MBO__D`0``'"+___0!```H(O__^@$``"`C/__.`4``-"3___H!0``\)7__QP&
M``#0EO__@`8``$"M___0!@``D*W__^@&``!@K___-`<``,"Q__]X!P``````
M`!0``````````7I2``%X$`$;#`<(D`$``!0````<````.'?__R8`````1`<0
M`````"0````T````,&[__W`#````#A!&#AA*#PMW"(``/QHY*C,D(@`````4
M````7````'AQ__\0```````````````4````=````'!Q__]@`P``````````
M``!(````C````+AW__^V`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!
M#CB#!T0.0`)<"@XX1`XP00XH0@X@0@X80@X00@X(20L`(````-@````L>/__
M@P````!!#A"#`D<.L`$"=`H.$$$."$$+0````/P```"8>/__9`$```!"#A".
M`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0`7X*#C!!#BA!#B!"#AA"#A!"#@A+
M"P!(````0`$``,1Y__]Y`@```$(.$(\"1`X8C@-"#B"-!$(.*(P%00XPA@9!
M#CB#!T<.8`,V`0H..$$.,$$.*$(.($(.&$(.$$(."$4+/````(P!``#X>___
MV`````!"#A"-`D(.&(P#00X@A@1!#BB#!4<.J"!)#L`@`G0*#BA!#B!!#AA"
M#A!"#@A!"Q@```#,`0``F'S__T\`````10X0@P)M#@@````0````Z`$``,Q\
M__\I`````````#@```#\`0``Z'S__]@`````1@X0C`)!#AB&`T$.((,$1PZ@
M($P.H$!)#L!``J<*#B!$#AA!#A!"#@A!"Q`````X`@``C'W__PD`````````
M8````$P"``"(??__$@(```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX
M@P='#K@@3`[P(0)Q"@XX00XP00XH0@X@0@X80@X00@X(1`L"N0[X(4\.@"):
M#O@A00[P(0```!@```"P`@``1'___R8`````10X0@P)<#@@````X````S`(`
M`%A___]1`0```$4.$(8"00X8@P-'#I@@20ZP(`+T"@X800X000X(1`M:"@X8
M2`X000X(30M(````"`,``'R`__]<!````$8.$(\"0@X8C@-"#B"-!$(.*(P%
M00XPA@9(#CB#!T0.4`/^`PH..$T.,$$.*$(.($(.&$(.$$(."$4+&````%0#
M``"0A/__:0````!(#B`"4`H."$@+`!@```!P`P``Y(3__[@`````10X000X(
M1P[@`0`\````C`,``(B%__].`0```$(.$(P"00X8A@-!#B"#!$@,"Z"`!%$-
M!T0.L(`$`N`*#B!!#AA!#A!"#@A+"P``%````,P#``"8AO__(0````!(#A!8
M#@@`3````.0#``"PAO__UP````!&#A".`D(.&(T#0@X@C`1(#BB&!4<.,(,&
M1`Y`?@H.,$8.*$$.($(.&$(.$$(."$@+9`Y(1PY080Y(00Y```"L````-`0`
M`$"'__]&!P```$8.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.L`,#
M+0(.N`-=#L`#7PZX`T(.L`,"?@H..$0.,$$.*$(.($(.&$(.$$(."$4+`T4!
M#K@#2P[``UH.N`-!#K`#6PZX`T0.P`-.#L@#20[0`TL.L`,#&@$*#CA$#C!!
M#BA"#B!"#AA"#A!"#@A-"P+I#K@#0P[``T8.N`-!#K`#`#````#D!```X(W_
M_Q@"````1@X0C`)(#AB&`T$.((,$1`XP`W(!"@X@00X800X00@X(1PLT````
M&`4``,R/___6`````$4.$(8"00X8@P-.#C`"3PH.&$$.$$$."$L+`E<*#AA$
M#A!!#@A%"R@```!0!0``]&___PP"````10X0A@)!#AB#`T0.4`-I`0H.&$,.
M$$$."$$+3````'P%``!(D/__:A8```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P='#M`%`TD6"@XX00XP00XH0@X@0@X80@X00@X(00L````4````
MS`4``&BF__])`````$@.$`)`#@A(````Y`4``*"F___)`0```$8.$(\"2`X8
MC@-&#B"-!$4.*(P%1`XPA@9!#CB#!T0.4`,6`0H..$$.,$$.*$(.($(.&$(.
M$$(."$8+0````#`&```DJ/__4P(```!&#A".`D8.&(T#0@X@C`1!#BB&!40.
M,(,&`YD!"@XH00X@0@X80@X00@X(30L````````0````=`8``$"J__\0````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/`I````````L"D```````!.<0```````.EP````````!G$```````!?
M<0````````$`````````\0(````````!``````````$#````````#```````
M````(`````````T`````````@&(````````9`````````,#+````````&P``
M```````(`````````!H`````````R,L````````<``````````@`````````
M]?[_;P````#0`P````````4`````````@`H````````&`````````"`$````
M````"@````````!:`P````````L`````````&``````````5````````````
M`````````P````````#PS0````````(`````````$`4````````4````````
M``<`````````%P````````#($`````````<`````````Z`X````````(````
M`````.`!````````"0`````````8`````````!X`````````"`````````#[
M__]O``````$```@`````_O__;P````!H#@```````/___V\``````0``````
M``#P__]O`````-H-````````^?__;P`````(````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````\,L`````````````````````````
M````,"````````!`(````````%`@````````8"````````!P(````````(`@
M````````D"````````"@(````````+`@````````P"````````#0(```````
M`.`@````````\"``````````(0```````!`A````````("$````````P(0``
M`````$`A````````4"$```````!@(0```````'`A````````@"$```````"0
M(0```````*`A````````L"$```````#`(0```````-`A````````X"$`````
M``#P(0`````````B````````$"(````````@(@```````#`B````````0"(`
M``````!0(@```````&`B````````<"(```````"`(@```````)`B````````
MH"(```````"P(@```````,`B````````T"(```````#@(@```````/`B````
M`````",````````0(P```````"`C````````,",```````!`(P```````%`C
M````````8",```````!P(P```````(`C````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T`````````I005(N<&T*``````````#X
M<@```````$=#0SH@*$UA9V5I82`Q-"XQ+C`M,"Y20RXR+FUG83$P*2`Q-"XQ
M+C`@,C`R-#`U,#,@*'!R97)E;&5A<V4I`$=#0SH@*$UA9V5I82`Q-"XR+C`M
M,2YM9V$Q,"D@,30N,BXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N<&QT
M+G-E8P`N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD871A+G)E;"YR;P`N9'EN
M86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M````````````````````````````````````````````````````````````
M```````+`````0````(`````````&`,````````8`P```````!P`````````
M```````````!````````````````````$P````<````"`````````#@#````
M````.`,```````!0````````````````````"````````````````````"8`
M```'`````@````````"(`P```````(@#````````)```````````````````
M``0````````````````````Y````!P````(`````````K`,```````"L`P``
M`````"`````````````````````$````````````````````1P```/;__V\"
M`````````-`#````````T`,```````!,``````````8`````````"```````
M`````````````%$````+`````@`````````@!````````"`$````````8`8`
M```````'`````0````@`````````&`````````!9`````P````(`````````
M@`H```````"`"@```````%H#```````````````````!````````````````
M````80```/___V\"`````````-H-````````V@T```````"(``````````8`
M`````````@`````````"`````````&X```#^__]O`@````````!H#@``````
M`&@.````````@``````````'`````0````@```````````````````!]````
M!`````(`````````Z`X```````#H#@```````.`!````````!@`````````(
M`````````!@`````````AP````0```!"`````````,@0````````R!``````
M```0!0````````8````9````"``````````8`````````)$````!````!@``
M````````(``````````@````````&P````````````````````0`````````
M``````````",`````0````8`````````("`````````@(````````'`#````
M```````````````0`````````!``````````EP````$````&`````````)`C
M````````D",````````0````````````````````$``````````0````````
M`*`````!````!@````````"@(P```````*`C````````8`,`````````````
M`````!``````````$`````````"I`````0````8``````````"<`````````
M)P```````(`[```````````````````@````````````````````KP````$`
M```&`````````(!B````````@&(````````-````````````````````!```
M`````````````````+4````!`````@``````````<`````````!P````````
ML$```````````````````!````````````````````"]`````0````(`````
M````L+````````"PL`````````0!```````````````````$````````````
M````````RP````$````"`````````+BQ````````N+$```````"(!@``````
M````````````"````````````````````-4````.`````P````````#`RP``
M`````,"[````````"`````````````````````@`````````"`````````#A
M````#P````,`````````R,L```````#(NP````````@`````````````````
M```(``````````@`````````[0````$````#`````````-#+````````T+L`
M```````@````````````````````"````````````````````/H````&````
M`P````````#PRP```````/"[``````````(````````'``````````@`````
M````$`````````";`````0````,`````````\,T```````#PO0```````!`"
M```````````````````(``````````@``````````P$```$````#````````
M``#0`````````,`````````H````````````````````"```````````````
M``````D!```(`````P````````!`T````````"C`````````6```````````
M`````````"`````````````````````.`0```0```#``````````````````
M```HP````````&,````````````````````!``````````$``````````0``
M``,`````````````````````````B\`````````7`0``````````````````
0`0``````````````````````
